@@ -270,7 +270,7 @@ class Handler(tornado.web.RequestHandler):
         if push_id:
             push = self.application.db.get_value("SELECT output FROM push WHERE id = ?", push_id)
             if push:
-                self.finish(push)
+                self.finish("<pre>%s</pre>" % push)
             else:
                 raise tornado.web.HTTPError(404)
         else:
